@@ -7,7 +7,7 @@ import random
 import string
 import time
 from pathlib import Path
-from flask import Flask, request, render_template
+from flask import Flask, request, render_template, Response
 from flask_restful import Resource, Api
 
 
@@ -286,10 +286,57 @@ def home():
     return render_template("index.html")
 
 
+@app.route("/favicon.ico")
+def favicon():
+    return ""
+
+
 @app.route("/<build_key>/")
 def build(build_key):
-    build = Build.get(build_key)
-    return render_template("build.html", build=build)
+    b = Build.get(build_key)
+    artifacts = [
+        "bmeta.json",
+        "build.log",
+        "kernel.config",
+        "status.json",
+    ]
+    if b["build_status"] == "pass":
+        artifacts += [
+            "modules.tar.xz",
+            "vmlinux.xz",
+            "zImage",
+        ]
+    if request.args.get("export", "") == "json":
+        data = {
+            "files": [
+                {
+                    "ETag": "abcdef01234567890",
+                    "LastModified": "Fri, 11 Sep 2020 18:31:41 GMT",
+                    "Size": 123,
+                    "Url": f"{request.scheme}://{request.host}/{build_key}/{f}",
+                }
+                for f in artifacts
+            ]
+        }
+        return Response(json.dumps(data), mimetype="application/json")
+
+    return render_template("build.html", build=b, files=artifacts)
+
+
+@app.route("/<build_key>/<filename>")
+def artifact(build_key, filename):
+    content_type = None
+    data = ""
+    if filename == "status.json":
+        data = json.dumps(Build.get(build_key))
+        content_type = "application/json"
+    elif filename == "build.log":
+        content_type = "text/plain"
+        data = "".join([f"log line {i} for {build_key}\n" for i in range(0, 10)])
+        build = Build.get(build_key)
+        if build["build_status"] == "fail":
+            data += "error: bla bla bla\n"
+    return Response(data, mimetype=content_type)
 
 
 @click.command()
