@@ -1,46 +1,34 @@
 # -*- coding: utf-8 -*-
 
-import requests as requests_orig
+import requests
 import tuxbuild.config
 import pytest
 
 
 @pytest.fixture(autouse=True)
-def requests(mocker):
-    """
-    Disables any real HTTP requests completely. This avoids the test suite
-    hitting the network for real.
-    """
-    mocker.patch("requests.delete")
-    mocker.patch("requests.get")
-    mocker.patch("requests.head")
-    mocker.patch("requests.post")
-    mocker.patch("requests.put")
-    return requests_orig
+def session(mocker):
+    mocker.patch("requests.Session.get")
+    mocker.patch("requests.Session.post")
+    return requests.Session
 
 
 @pytest.fixture
-def response(requests):
+def response():
     r = requests.Response()
     r.status_code = 200
     return r
 
 
 @pytest.fixture
-def post(requests, response):
-    requests.post.return_value = response
-    return requests.post
+def post(session, response):
+    session.post.return_value = response
+    return session.post
 
 
 @pytest.fixture
-def get(requests, response):
-    requests.get.return_value = response
-    return requests.get
-
-
-@pytest.fixture
-def sleep(mocker):
-    return mocker.patch("time.sleep")
+def get(session, response):
+    session.get.return_value = response
+    return session.get
 
 
 @pytest.fixture
