@@ -1,4 +1,4 @@
-TEST_DIRNAME=${0%/*}
+TEST_DIRNAME=$(readlink -f ${0%/*})
 
 run() {
   status=0
@@ -46,10 +46,12 @@ sets:
       - {target_arch: i386, toolchain: gcc-9, kconfig: allmodconfig}
       - {target_arch: riscv, toolchain: gcc-9, kconfig: allyesconfig}
 EOF
+
+    cd "${tmpdir}"
 }
 
 api_v1() {
-    nohup python3 "${TEST_DIRNAME}/../api_v1.py" --port=5001 "$@" > "${tmpdir}/api.log" 2>&1 3>&- &
+    HOME="${tmpdir}" nohup python3 "${TEST_DIRNAME}/../api_v1.py" --port=5001 "$@" > "${tmpdir}/api.log" 2>&1 3>&- &
     echo "$!" > "${tmpdir}/api.pid"
 }
 
@@ -61,3 +63,13 @@ tearDown() {
     fi
     rm -f "${tmpdir}/api.log"
 }
+
+if [ $# -gt 0 ]; then
+  export TESTCASES="$(echo "$@")"
+  set --
+  suite() {
+    for t in $TESTCASES; do
+      suite_addTest "$t"
+    done
+  }
+fi
