@@ -6,9 +6,9 @@ import json
 import queue
 import random
 import re
-import requests
 import time
 import tuxbuild.exceptions
+import tuxbuild.requests
 import uuid
 
 # We will poll for status change for an average duration of 180 minutes
@@ -17,49 +17,25 @@ delay_status_update = 30
 
 
 def post_request(url, headers, request):
-    retry_attempts = 3
-    for i in range(1, retry_attempts + 1):
-        try:
-            response = requests.post(url, data=json.dumps(request), headers=headers)
-        except requests.exceptions.ConnectionError as e:
-            # We are getting exception from either from Network error
-            if i == retry_attempts:
-                raise e
-            else:
-                time.sleep(random.randrange(15))
-                continue
-        if response.ok:
-            return json.loads(response.text)
+    response = tuxbuild.requests.post(url, data=json.dumps(request), headers=headers)
+    if response.ok:
+        return json.loads(response.text)
+    else:
+        if response.status_code == 400:
+            response_data = json.loads(response.text)
+            raise tuxbuild.exceptions.BadRequest(
+                f"{response_data.get('status_message')}"
+            )
         else:
-            if response.status_code == 400:
-                response_data = json.loads(response.text)
-                raise tuxbuild.exceptions.BadRequest(
-                    f"{response_data.get('status_message')}"
-                )
-            elif response.status_code in [500, 504] and i < retry_attempts:
-                time.sleep(random.randrange(15))
-            else:
-                response.raise_for_status()
+            response.raise_for_status()
 
 
 def get_request(url, headers):
-    retry_attempts = 30
-    for i in range(1, retry_attempts + 1):
-        try:
-            r = requests.get(url, headers=headers)
-        except requests.exceptions.ConnectionError as e:
-            # We are getting exception from either from Network error
-            if i == retry_attempts:
-                raise e
-            else:
-                time.sleep(random.randrange(15))
-                continue
-        if r.status_code == 200:
-            return json.loads(r.text)
-        elif r.status_code in [500, 504, 400] and i < retry_attempts:
-            time.sleep(random.randrange(15))
-        else:
-            r.raise_for_status()  # Some unexpected status that's not caught
+    response = tuxbuild.requests.get(url, headers=headers)
+    if response.status_code == 200:
+        return json.loads(response.text)
+    else:
+        response.raise_for_status()  # Some unexpected status that's not caught
 
 
 @attrs(kw_only=True)
@@ -173,12 +149,12 @@ class Build:
 
     def wait_on_status(self, status):
         """
-            Wait until the given status changes
+        Wait until the given status changes
 
-            For example, if status is 'queued', wait_for_status
-            will return once the status is no longer 'queued'
+        For example, if status is 'queued', wait_for_status
+        will return once the status is no longer 'queued'
 
-            Will timeout after state_timeout
+        Will timeout after state_timeout
         """
         timeout = time.time() + state_timeout
 
