@@ -3,8 +3,10 @@
 import click
 from functools import wraps
 import json
+import os
 import sys
 import tuxbuild
+import tuxbuild.download
 import tuxbuild.exceptions
 import tuxbuild.gitutils
 
@@ -93,6 +95,19 @@ def common_options(required):
             help="Write json build status out to a named file path",
             type=click.File("w", encoding="utf-8"),
         ),
+        option(
+            "-d",
+            "--download",
+            default=False,
+            is_flag=True,
+            help="Download artifacts after builds finish",
+        ),
+        option(
+            "-o",
+            "--output-dir",
+            default=".",
+            help="Directory where to download artifacts",
+        ),
         option(
             "-q",
             "--quiet",
@@ -100,6 +115,13 @@ def common_options(required):
             is_flag=True,
             help="Supress all informational output; prints only the download URL for the build",
         ),
+        option(
+            "-s",
+            "--show-logs",
+            default=False,
+            is_flag=True,
+            help="Prints build logs to stderr in case of warnings or errors",
+        ),
     ]
 
     def wrapper(f):
@@ -126,9 +148,31 @@ def process_git_head(f):
     return wrapper
 
 
+def show_log(build, download, output_dir):
+    if not build.warnings_count and not build.errors_count:
+        return
+    print("📄 Logs for {}:".format(build), file=sys.stderr)
+    sys.stderr.flush()
+    if download:
+        for line in open(os.path.join(output_dir, build.build_key, "build.log")):
+            print(line.strip(), file=sys.stderr)
+    else:
+        tuxbuild.download.download_file(
+            os.path.join(build.build_data, "build.log"), sys.stderr.buffer
+        )
+
+
 @cli.command()
 @common_options(required=["--target-arch", "--kconfig", "--toolchain"])
-def build(json_out=None, quiet=False, git_head=False, **build_params):
+def build(
+    json_out=None,
+    quiet=False,
+    show_logs=None,
+    git_head=False,
+    download=False,
+    output_dir=None,
+    **build_params,
+):
     quiet_output(quiet)
 
     try:
@@ -147,6 +191,10 @@ def build(json_out=None, quiet=False, git_head=False, **build_params):
     build_result = wait_for_object(build)
     if json_out:
         json_out.write(json.dumps(build.status, sort_keys=True, indent=4))
+    if download:
+        tuxbuild.download.download(build, output_dir)
+    if show_logs:
+        show_log(build, download, output_dir)
     if quiet:
         print(build.build_data)
     if not build_result:
@@ -158,7 +206,15 @@ def build(json_out=None, quiet=False, git_head=False, **build_params):
 @click.option("--tux-config", help="Path or a web URL to tuxbuild config file")
 @common_options(required=[])
 def build_set(
-    tux_config, set_name, json_out=None, quiet=None, git_head=False, **build_params
+    tux_config,
+    set_name,
+    json_out=None,
+    quiet=None,
+    show_logs=None,
+    git_head=False,
+    download=False,
+    output_dir=None,
+    **build_params,
 ):
     quiet_output(quiet)
 
@@ -180,6 +236,14 @@ def build_set(
     if json_out:
         json_out.write(json.dumps(build_set.status_list, sort_keys=True, indent=4))
 
+    if download:
+        for build in build_set.builds:
+            tuxbuild.download.download(build, output_dir)
+
+    if show_logs:
+        for build in build_set.builds:
+            show_log(build, download, output_dir)
+
     if quiet:
         for build in build_set.builds:
             print(build.build_data)
